@@ -18,7 +18,6 @@
 from __future__ import annotations
 
 import logging
-import logging.config
 import re
 from importlib import reload
 from unittest import mock
@@ -27,13 +26,13 @@ from unittest.mock import patch
 import pytest
 from kubernetes.client import models as k8s
 
-from airflow.config_templates.airflow_local_settings import DEFAULT_LOGGING_CONFIG
 from airflow.executors import executor_loader
 from airflow.models.dag import DAG
 from airflow.models.taskinstance import TaskInstance
 from airflow.utils.log.file_task_handler import (
     FileTaskHandler,
 )
+from airflow.utils.log.log_reader import TaskLogReader
 from airflow.utils.log.logging_mixin import set_context
 from airflow.utils.state import State, TaskInstanceState
 from airflow.utils.types import DagRunType
@@ -66,7 +65,6 @@ class TestFileTaskLogHandler:
             clear_db_dag_bundles()
 
     def setup_method(self):
-        logging.config.dictConfig(DEFAULT_LOGGING_CONFIG)
         logging.root.disabled = False
         self.clean_up()
         # We use file task handler by default.
@@ -102,7 +100,7 @@ class TestFileTaskLogHandler:
             mock_k8s_get_task_log.assert_not_called()
 
     @pytest.mark.parametrize(
-        "pod_override, namespace_to_call",
+        ("pod_override", "namespace_to_call"),
         [
             pytest.param(k8s.V1Pod(metadata=k8s.V1ObjectMeta(namespace="namespace-A")), "namespace-A"),
             pytest.param(k8s.V1Pod(metadata=k8s.V1ObjectMeta(namespace="namespace-B")), "namespace-B"),
@@ -156,7 +154,7 @@ class TestFileTaskLogHandler:
         logger = ti.log
         ti.task.log.disabled = False
 
-        file_handler = next((h for h in logger.handlers if h.name == FILE_TASK_HANDLER), None)
+        file_handler = TaskLogReader().log_handler
         set_context(logger, ti)
         ti.run(ignore_ti_state=True)
         ti.state = TaskInstanceState.RUNNING
